import cvxpy as cvx
import numpy as np
import matplotlib.pyplot as plt 

def plotDecisionBoundary(X, Y, beta_value, beta0_value, plotName, title, xlab, ylab):
    '''
    X (2,n): Array of features
    Y (n,): Array of labels

    beta_value (2,): list of betas correspoding to X features
    beta0_value (scalar): value of intercept beta_0

    plotName (str): Name of plot for saving
    title (str): Plot title
    xlab (str): X-label 
    ylab (str): Y-label
    '''
    X_dim0_range = X[:,0].min(), X[:,0].max()
    X_dim0_samples = np.linspace(*X_dim0_range, 100)
    X_dim1_samples = (-beta0_value - beta_value[0]*X_dim0_samples) / beta_value[1]
    plt.figure()
    plt.plot(X_dim0_samples, X_dim1_samples)
    plt.scatter(X[:,0], X[:,1], c=Y)
    plt.title(title)
    plt.xlabel(xlab)
    plt.ylabel(ylab)
    plt.savefig(plotName + '.png')
